@@ -17,14 +17,15 @@ def logger(filepath=None, filehandler=True, streamhandler=True):
     # 2. 如果为文件，则直接使用
     # 3. 如果为空、非文件、非文件夹、文件夹或文件不存在等其他情况，则指定当前路径下写入日志
     # 一并返回绝对路径
-    filename = f"{datetime.datetime.now().strftime('%Y-%m-%d.%H-%M-%S')}.log"
+    file_name = f"{datetime.datetime.now().strftime('%Y-%m-%d.%H-%M-%S')}.log"
     # 文件夹
     if filepath and os.path.isdir(filepath):
-        filepath = os.path.join(filepath, filename)
+        filepath = os.path.join(filepath, file_name)
     # 非空的文件、文件夹、相对路径的文件、相对路径的文件夹
     elif (not filepath):
-        filepath = filename
+        filepath = file_name
     filepath = os.path.abspath(filepath)
+
     # create logger with a name
     logger = logging.getLogger()
     if not logger.handlers:
@@ -46,6 +47,6 @@ def logger(filepath=None, filehandler=True, streamhandler=True):
             ch.setFormatter(formatter)
             logger.addHandler(ch)
 
-    # # 第一条日志，记录日志文件所在位置
-    # logger.info(f'filepath: {filepath}')
+    # 第一条日志，记录日志文件所在位置
+    logger.info(f'filepath: {filepath}')
     return logger
